@@ -9,7 +9,7 @@ use Net::SSLeay ();
 extends "Archive::BagIt";
 
 
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.085'; # VERSION
 
 # ABSTRACT: A module to use L<IO::AIO> to get better performance
 
@@ -112,7 +112,7 @@ Archive::BagIt::Fast - A module to use L<IO::AIO> to get better performance
 
 =head1 VERSION
 
-version 0.083
+version 0.085
 
 =head1 NAME
 
@@ -155,11 +155,11 @@ web interface at L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-Rob Schmidt <rjeschmi@gmail.com>
+Andreas Romeyke <cpan@andreas.romeyke.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt <rjeschmi@gmail.com>, William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
