@@ -5,7 +5,7 @@ use Carp qw( croak );
 use Moo;
 use namespace::autoclean;
 with 'Archive::BagIt::Role::Algorithm', 'Archive::BagIt::Role::OpenSSL';
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.085'; # VERSION
 # ABSTRACT: The MD5 algorithm plugin (default for v0.97)
 
 has '+plugin_name' => (
@@ -46,7 +46,7 @@ Archive::BagIt::Plugin::Algorithm::MD5 - The MD5 algorithm plugin (default for v
 
 =head1 VERSION
 
-version 0.083
+version 0.085
 
 =head1 AVAILABILITY
 
@@ -61,11 +61,11 @@ web interface at L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-Rob Schmidt <rjeschmi@gmail.com>
+Andreas Romeyke <cpan@andreas.romeyke.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt <rjeschmi@gmail.com>, William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
