@@ -5,7 +5,7 @@ use Moo::Role;
 use IO::Async::Loop;
 use namespace::autoclean;
 # ABSTRACT: A role that handles plugin loading
-our $VERSION = '0.083'; # VERSION
+our $VERSION = '0.085'; # VERSION
 
 has plugin_name => (
   is  => 'ro',
@@ -48,7 +48,7 @@ Archive::BagIt::Role::Plugin - A role that handles plugin loading
 
 =head1 VERSION
 
-version 0.083
+version 0.085
 
 =head1 AVAILABILITY
 
@@ -63,11 +63,11 @@ web interface at L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-Rob Schmidt <rjeschmi@gmail.com>
+Andreas Romeyke <cpan@andreas.romeyke.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Rob Schmidt and William Wueppelmann and Andreas Romeyke.
+This software is copyright (c) 2021 by Rob Schmidt <rjeschmi@gmail.com>, William Wueppelmann and Andreas Romeyke.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
